==> update_3.x_2.14.11.zip: components/com_pixelcms_articles/views/pixelcms_news/tmpl/default_listing.php <==
<?php
$CMS_URL = 'https://cms.pixel-kraft.de';

$html[] = "";

foreach ($this->news as $article) {
    $link = JRoute::_("index.php?option=com_pixelcms_articles&view=pixelcms_news&articleId=$article->uid&Itemid=$this->item_id");
    $html[] = "<div class='cms_news'>";
    if ($article->images) {
        echo '<pre style="display: none;">'.print_r($this->params, 1).'</pre>';
        if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
            $html[] = "<div class='cms_news__image' style='background-image: url({$article->images[0]})'></div>";
        } else {
            $html[] = "<div class='cms_news__image'><img src='{$article->images[0]}'></div>";
        }
    } else {
        $html[] = "<div class='cms_news__image'></div>";
    }
    $html[] = "<div class=\"cms_news__content\">";
    $html[] = "<img" . (($article->manufacturer->color) ? ' style="background-color: '.$article->manufacturer->color.'"' : '') . " class=\"cms_news__manufacturer\" src=\"//cms.pixel-kraft.de/{$article->manufacturer->image}\">";
    $html[] = "<span class='cms_article__date'>" . DateTime::createFromFormat('Y-m-d H:i:s', $article->datetime)->format('d.m.Y') . "</span>";
    $html[] = "<a href='$link'><h2 class='cms_news__headline'>$article->title</h2></a>";

    $intro_text = substr($article->short, 0, $this->intro_length);

    if (strlen($intro_text) < strlen($article->short)) {
        $intro_text .= '…';
    }

    $html[] = "<p class='cms_news__intro'>$intro_text</p>";
    $html[] = "<a class=\"cms_news__readmore\" href=\"$link\">Weiterlesen</a>";
    $html[] = "</div>";
    $html[] = "</div>";
}

echo implode("\n", $html);

==> update_3.x_2.14.16.zip: components/com_pixelcms_articles/views/pixelcms_news/tmpl/default_listing.php <==
<?php
$CMS_URL = 'https://cms.pixel-kraft.de';

$html[] = "";

foreach ($this->news as $article) {
    $link = JRoute::_("index.php?option=com_pixelcms_articles&view=pixelcms_news&articleId=$article->uid&Itemid=$this->item_id");
    $html[] = "<div class='cms_news'>";
    if ($article->images) {
        if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
            $html[] = "<div class='cms_news__image' style='background-image: url({$article->images[0]})'></div>";
        } else {
            $html[] = "<div class='cms_news__image'><img src='{$article->images[0]}'></div>";
        }
    } else {
        $html[] = "<div class='cms_news__image'></div>";
    }
    $html[] = "<div class=\"cms_news__content\">";
    $html[] = "<img" . (($article->manufacturer->color) ? ' style="background-color: '.$article->manufacturer->color.'"' : '') . " class=\"cms_news__manufacturer\" src=\"//cms.pixel-kraft.de/{$article->manufacturer->image}\">";
    $html[] = "<span class='cms_article__date'>" . DateTime::createFromFormat('Y-m-d H:i:s', $article->datetime)->format('d.m.Y') . "</span>";
    $html[] = "<a href='$link'><h2 class='cms_news__headline'>$article->title</h2></a>";

    $intro_text = substr($article->short, 0, $this->params->get('intro_length'));

    if (strlen($intro_text) < strlen($article->short)) {
        $intro_text .= '…';
    }

    $html[] = "<p class='cms_news__intro'>$intro_text</p>";
    $html[] = "<a class=\"cms_news__readmore\" href=\"$link\">Weiterlesen</a>";
    $html[] = "</div>";
    $html[] = "</div>";
}

echo implode("\n", $html);
